@@ -2,11 +2,20 @@ from typing import List
 from functools import reduce
 from dateutil.parser import parse
 from statistics import mean
+import re
 
 
 def _flatten(values: list): return list(reduce(lambda x, y: x + (y if isinstance(y, list) else [y]), values, []))
 
 
+def _next_error(values: list): return next((x for x in values if x is not True), True)
+
+
+def _filter_list_errors(values: list):
+    values = list(filter(lambda x: x is not True, values))
+    return True if len(values) == 0 else (values[0] if len(values) == 1 else values)
+
+
 def _safe_cast(val, to_type, default=None):
     try:
         return to_type(val)
@@ -31,6 +40,9 @@ def _diff_in_days(from_date: str, to_date: str):
     return round(difference.days + difference.seconds/86400, 1)
 
 
+def _is_in_days(date: str): return date is not None and re.compile(r'^[\d]{4}\-[\d]{2}\-[\d]{2}').match(date)
+
+
 def _value_range_error(value: int, minimum: int, maximum: int):
     return 'minimum' if minimum is not None and value < minimum else \
         'maximum' if maximum is not None and value > maximum else False
@@ -57,6 +69,7 @@ def _same_properties(value: dict, props: List[str]):
     return identical
 
 
-def _value_average(node: dict, default=0):
-    value = node.get('value')
-    return mean(value) if value is not None and isinstance(value, list) else default
+def _average(value, default=0): return mean(value) if value is not None and isinstance(value, list) else default
+
+
+def _value_average(node: dict, default=0): return _average(node.get('value'), default)
