@@ -1,4 +1,4 @@
-from hestia_earth.validation.utils import _list_has_props, _diff_in_years
+from hestia_earth.validation.utils import _filter_list_errors, _list_has_props, _diff_in_years
 
 
 def validate_lifespan(infrastructure: list):
@@ -13,4 +13,4 @@ def validate_lifespan(infrastructure: list):
         }
 
     results = list(map(validate, enumerate(_list_has_props(infrastructure, ['lifespan', 'startDate', 'endDate']))))
-    return next((x for x in results if x is not True), True)
+    return _filter_list_errors(results)
