@@ -3,7 +3,8 @@ from hestia_earth.utils.model import find_term_match
 from hestia_earth.utils.lookup import download_lookup, get_table_value, column_name
 from hestia_earth.utils.tools import non_empty_list, safe_parse_float
 
-from hestia_earth.validation.utils import _flatten, _list_has_props, _value_range_error, _value_average
+from hestia_earth.validation.utils import _flatten, _filter_list_errors, _list_has_props, _value_range_error, \
+    _value_average
 
 
 SOIL_TEXTURE_IDS = ['sandContent', 'siltContent', 'clayContent']
@@ -93,7 +94,7 @@ def validate_depths(measurements: list):
         }
 
     results = list(map(validate, enumerate(_list_has_props(measurements, ['depthUpper', 'depthLower']))))
-    return next((x for x in results if x is not True), True)
+    return _filter_list_errors(results)
 
 
 def validate_value_min_max(measurements: list):
@@ -115,5 +116,4 @@ def validate_value_min_max(measurements: list):
             'message': f"should be below {maximum}"
         })
 
-    results = list(map(validate, enumerate(measurements)))
-    return next((x for x in results if x is not True), True)
+    return _filter_list_errors(list(map(validate, enumerate(measurements))))
