@@ -3,7 +3,7 @@ import re
 
 from hestia_earth.validation.geojson import _get_geojson_area
 from hestia_earth.validation.gadm import _get_gadm_data
-from hestia_earth.validation.utils import _same_properties, _value_average
+from hestia_earth.validation.utils import _filter_list_errors, _next_error, _same_properties, _value_average
 
 
 def validate_dates(node: dict):
@@ -22,22 +22,36 @@ def validate_list_dates(node: dict, list_key: str):
             'message': 'must be greater than startDate'
         }
 
-    results = list(map(validate, enumerate(node.get(list_key, []))))
-    return next((x for x in results if x is not True), True)
+    return _filter_list_errors(list(map(validate, enumerate(node.get(list_key, [])))))
+
+
+def _compare_min_max(value1, value2): return value1 <= value2
+
+
+def _compare_list_min_max(list1: list, list2: list):
+    def compare_enum(index: int):
+        valid = _compare_min_max(list1[index], list2[index])
+        return True if valid is True else index
+
+    return len(list1) != len(list2) or \
+        next((x for x in list(map(compare_enum, range(len(list1)))) if x is not True), True)
 
 
 def validate_list_min_max(node: dict, list_key: str):
     def validate(values):
         value = values[1]
         index = values[0]
-        return value.get('min', 0) <= value.get('max', 0) or {
+        min = value.get('min', 0)
+        max = value.get('max', 0)
+        compare_lists = isinstance(min, list) and isinstance(max, list)
+        is_valid = _compare_list_min_max(min, max) if compare_lists else _compare_min_max(min, max)
+        return is_valid is True or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].max",
             'message': 'must be greater than min'
         }
 
-    results = list(map(validate, enumerate(node.get(list_key, []))))
-    return next((x for x in results if x is not True), True)
+    return _next_error(list(map(validate, enumerate(node.get(list_key, [])))))
 
 
 def validate_list_duplicates(node: dict, list_key: str, props: List[str]):
@@ -53,24 +67,31 @@ def validate_list_duplicates(node: dict, list_key: str, props: List[str]):
             'message': f"Duplicates found. Please make sure there is only one entry with the same {', '.join(props)}"
         }
 
-    results = list(map(validate, enumerate(node.get(list_key, []))))
-    return next((x for x in results if x is not True), True)
+    return _next_error(list(map(validate, enumerate(node.get(list_key, [])))))
 
 
 def validate_list_term_percent(node: dict, list_key: str):
-    def validate(values):
-        index = values[0]
-        value = values[1]
-        units = value.get('term', {}).get('units', '')
-        value = _value_average(value)
-        return units != '% (0-100)' or value is None or type(value) == str or (0 <= value and value <= 100) or {
+    def soft_validate(index: int, value): return 0 <= value and value <= 1 and {
+            'level': 'warning',
+            'dataPath': f".{list_key}[{index}].value",
+            'message': 'may be between 0 and 100'
+        }
+
+    def hard_validate(index: int, value): return (0 <= value and value <= 100) or {
             'level': 'error',
             'dataPath': f".{list_key}[{index}].value",
             'message': 'should be between 0 and 100 (percentage)'
         }
 
-    results = list(map(validate, enumerate(node.get(list_key, []))))
-    return next((x for x in results if x is not True), True)
+    def validate(values):
+        index = values[0]
+        value = values[1]
+        units = value.get('term', {}).get('units', '')
+        value = _value_average(value)
+        return units != '% (0-100)' or value is None or type(value) == str or \
+            soft_validate(index, value) or hard_validate(index, value)
+
+    return _filter_list_errors(list(map(validate, enumerate(node.get(list_key, [])))))
 
 
 def validate_region(node: dict, region_key='region'):
