@@ -1,5 +1,6 @@
 from hestia_earth.schema import SiteSiteType
 
+from hestia_earth.validation.utils import _flatten
 from .shared import validate_dates, validate_list_dates, validate_list_duplicates, \
     validate_list_min_max, validate_region, validate_country, validate_coordinates, need_validate_coordinates, \
     validate_area, need_validate_area, validate_list_term_percent
@@ -50,7 +51,7 @@ def validate_site(site: dict):
         validate_region(site) if 'region' in site else True,
         validate_coordinates(site) if validate_site_coordinates(site) else True,
         validate_area(site) if need_validate_area(site) else True
-    ] + ([
+    ] + _flatten([
         validate_list_dates(site, 'measurements'),
         validate_list_min_max(site, 'measurements'),
         validate_list_term_percent(site, 'measurements'),
@@ -66,10 +67,10 @@ def validate_site(site: dict):
             'depthUpper',
             'depthLower'
         ])
-    ] if 'measurements' in site else []) + ([
+    ] if 'measurements' in site else []) + _flatten([
         validate_list_dates(site, 'infrastructure'),
         validate_lifespan(site.get('infrastructure'))
-    ] if 'infrastructure' in site else []) + ([
+    ] if 'infrastructure' in site else []) + _flatten([
         validate_list_dates(site, 'practices'),
         validate_list_min_max(site, 'practices'),
         validate_list_term_percent(site, 'practices'),
